@@ -1,18 +1,23 @@
 import warnings
 
 import numpy as np
+import pandas as pd
 
 from featuretools.primitives.base.transform_primitive_base import (
     TransformPrimitive
 )
 from featuretools.utils import convert_time_units
+from featuretools.utils.common_tld_utils import COMMON_TLDS
 from featuretools.utils.entity_utils import replace_latlong_nan
 from featuretools.utils.gen_utils import Library
 from featuretools.variable_types import (
+    URL,
     Boolean,
+    Categorical,
     DateOfBirth,
     Datetime,
     DatetimeTimeIndex,
+    EmailAddress,
     LatLong,
     NaturalLanguage,
     Numeric,
@@ -693,3 +698,179 @@ class Age(TransformPrimitive):
         def age(x, time=None):
             return (time - x).dt.days / 365
         return age
+
+
+class URLToDomain(TransformPrimitive):
+    """Determines the domain of a url.
+
+    Description:
+        Calculates the label to identify the network domain of a URL. Supports
+        urls with or without protocol as well as international country domains.
+
+    Examples:
+        >>> url_to_domain = URLToDomain()
+        >>> urls =  ['https://play.google.com',
+        ...          'http://www.google.co.in',
+        ...          'www.facebook.com']
+        >>> url_to_domain(urls).tolist()
+        ['play.google.com', 'google.co.in', 'facebook.com']
+    """
+    name = "url_to_domain"
+    input_types = [URL]
+    return_type = Categorical
+
+    def get_function(self):
+        def url_to_domain(x):
+            p = r'^(?:https?:\/\/)?(?:[^@\/\n]+@)?(?:www\.)?([^:\/?\n]+)'
+            return x.str.extract(p, expand=False)
+        return url_to_domain
+
+
+class URLToProtocol(TransformPrimitive):
+    """Determines the protocol (http or https) of a url.
+
+    Description:
+        Extract the protocol of a url using regex.
+        It will be either https or http. Returns nan if
+        the url doesn't contain a protocol.
+
+    Examples:
+        >>> url_to_protocol = URLToProtocol()
+        >>> urls =  ['https://play.google.com',
+        ...          'http://www.google.co.in',
+        ...          'www.facebook.com']
+        >>> url_to_protocol(urls).to_list()
+        ['https', 'http', nan]
+    """
+    name = "url_to_protocol"
+    input_types = [URL]
+    return_type = Categorical
+
+    def get_function(self):
+        def url_to_protocol(x):
+            p = r'^(https|http)(?:\:)'
+            return x.str.extract(p, expand=False)
+        return url_to_protocol
+
+
+class URLToTLD(TransformPrimitive):
+    """Determines the top level domain of a url.
+
+    Description:
+        Extract the top level domain of a url, using regex,
+        and a list of common top level domains. Returns nan if
+        the url is invalid or null.
+        Common top level domains were pulled from this list:
+        https://www.hayksaakian.com/most-popular-tlds/
+
+    Examples:
+        >>> url_to_tld = URLToTLD()
+        >>> urls = ['https://www.google.com', 'http://www.google.co.in',
+        ...         'www.facebook.com']
+        >>> url_to_tld(urls).to_list()
+        ['com', 'in', 'com']
+    """
+    name = "url_to_tld"
+    input_types = [URL]
+    return_type = Categorical
+
+    def get_function(self):
+        self.tlds_pattern = r'(?:\.({}))'.format('|'.join(COMMON_TLDS))
+
+        def url_to_domain(x):
+            p = r'^(?:https?:\/\/)?(?:[^@\/\n]+@)?(?:www\.)?([^:\/?\n]+)'
+            return x.str.extract(p, expand=False)
+
+        def url_to_tld(x):
+            domains = url_to_domain(x)
+            df = domains.str.extractall(self.tlds_pattern)
+            matches = df.groupby(level=0).last()[0]
+            return matches.reindex(x.index)
+        return url_to_tld
+
+
+class IsFreeEmailDomain(TransformPrimitive):
+    """Determines if an email address is from a free email domain.
+
+    Description:
+        EmailAddress input should be a string. Will return Nan
+        if an invalid email address is provided, or if the input is
+        not a string. The list of free email domains used in this primitive
+        was obtained from https://github.com/willwhite/freemail/blob/master/data/free.txt.
+
+    Examples:
+        >>> is_free_email_domain = IsFreeEmailDomain()
+        >>> is_free_email_domain(['name@gmail.com', 'name@featuretools.com']).tolist()
+        [True, False]
+    """
+    name = "is_free_email_domain"
+    input_types = [EmailAddress]
+    return_type = Boolean
+
+    filename = "free_email_provider_domains.txt"
+
+    def get_function(self):
+        file_path = self.get_filepath(self.filename)
+
+        free_domains = pd.read_csv(file_path, header=None, names=['domain'])
+        free_domains['domain'] = free_domains.domain.str.strip()
+
+        def is_free_email_domain(emails):
+            # if the input is empty return an empty Series
+            if len(emails) == 0:
+                return pd.Series([])
+
+            emails_df = pd.DataFrame({'email': emails})
+
+            # if all emails are NaN expand won't propogate NaNs and will fail on indexing
+            if emails_df['email'].isnull().all():
+                emails_df['domain'] = np.nan
+            else:
+                # .str.strip() and .str.split() return NaN for NaN values and propogate NaNs into new columns
+                emails_df['domain'] = emails_df['email'].str.strip().str.split('@', expand=True)[1]
+
+            emails_df['is_free'] = emails_df['domain'].isin(free_domains['domain'])
+
+            # if there are any NaN domain values, change the series type to allow for
+            # both bools and NaN values and set is_free to NaN for the NaN domains
+            if emails_df['domain'].isnull().values.any():
+                emails_df['is_free'] = emails_df['is_free'].astype(np.object)
+                emails_df.loc[emails_df['domain'].isnull(), 'is_free'] = np.nan
+            return emails_df.is_free.values
+        return is_free_email_domain
+
+
+class EmailAddressToDomain(TransformPrimitive):
+    """Determines the domain of an email
+
+    Description:
+        EmailAddress input should be a string. Will return Nan
+        if an invalid email address is provided, or if the input is
+        not a string.
+
+    Examples:
+        >>> email_address_to_domain = EmailAddressToDomain()
+        >>> email_address_to_domain(['name@gmail.com', 'name@featuretools.com']).tolist()
+        ['gmail.com', 'featuretools.com']
+    """
+    name = "email_address_to_domain"
+    input_types = [EmailAddress]
+    return_type = Categorical
+
+    def get_function(self):
+        def email_address_to_domain(emails):
+            # if the input is empty return an empty Series
+            if len(emails) == 0:
+                return pd.Series([])
+
+            emails_df = pd.DataFrame({'email': emails})
+
+            # if all emails are NaN expand won't propogate NaNs and will fail on indexing
+            if emails_df['email'].isnull().all():
+                emails_df['domain'] = np.nan
+                emails_df['domain'] = emails_df['domain'].astype(object)
+            else:
+                # .str.strip() and .str.split() return NaN for NaN values and propogate NaNs into new columns
+                emails_df['domain'] = emails_df['email'].str.strip().str.split('@', expand=True)[1]
+            return emails_df.domain.values
+        return email_address_to_domain
